Queue

Struct Queue 

pub struct Queue(/* private fields */);
The Queue connects a host program to a single device. Programs submit tasks to a device via the Queue and may monitor the Queue for completion. A program initiates the task by submitting a kernel.

Implementations

Source

impl Queue

pub fn new() -> Self

Construct a Queue based on the device returned from the default selector.

pub fn new_immediate() -> Self

Construct an immediate Queue based on the device returned from the default selector.

pub fn get_context(&self) -> Context

Returns the SYCL queue’s context.

pub fn alloc_host<T: Pod>(&mut self, len: usize) -> EnqueuedHostBuffer<T>

Allocates zeroed memory and creates a host-side Buffer that can store an array of T.

pub fn alloc_shared<T: Pod>(&mut self, len: usize) -> EnqueuedSharedBuffer<T>

Allocates zeroed memory and creates a shared Buffer that can store an array of T.

pub fn alloc_device<T: Pod>(&mut self, len: usize) -> EnqueuedDeviceBuffer<T>

Allocates zeroed memory and creates a device Buffer that can store an array of T.

pub unsafe fn alloc_uninit_host<T>(&self, len: usize) -> HostBuffer<T>

Allocates memory and creates a host-side Buffer that can store an array of T. Safety: the buffer contents are uninitialized.

pub unsafe fn alloc_uninit_shared<T>(&self, len: usize) -> SharedBuffer<T>

Allocates memory and creates a shared Buffer that can store an array of T. Safety: the buffer contents are uninitialized.

pub unsafe fn alloc_uninit_device<T>(&self, len: usize) -> DeviceBuffer<T>

Allocates memory and creates a device-side Buffer that can store an array of T. Safety: the buffer contents are uninitialized.

pub unsafe fn memset<T, A: UsmAlloc>( &mut self, buffer: &mut Buffer<T, A>, value: i32, ) -> Event

Sets memory allocated with USM allocations. Safety: the caller must make sure the underlying memory isn’t being aliased somewhere else.

pub unsafe fn memset_with_deps<T, A: UsmAlloc>( &mut self, buffer: &mut Buffer<T, A>, value: i32, dep_events: &[&Event], ) -> Event

Sets memory allocated with USM allocations after all specified events finish. Safety: the caller must make sure the underlying memory isn’t being aliased somewhere else.

pub fn barrier(&mut self) -> Event

Submits a barrier to the queue.

pub fn barrier_with_deps(&mut self, dep_events: &[&Event]) -> Event

Submits a barrier to the queue after all specified events finish.

pub fn wait(&mut self)

Performs a blocking wait for the completion of all enqueued tasks in the queue.

pub unsafe fn launch<const ARGC: usize, const DIMENSIONS: usize>( &mut self, nd_range: NdRange<DIMENSIONS>, kernel: &Kernel, args: impl KernelArgumentList<ARGC>, ) -> Event
where NdRange<DIMENSIONS>: ValidDimension,

Enqueues a kernel object to the queue as an ND-range kernel, using the number of work-items specified by the NdRange nd_range.

pub fn copy<T, A1, A2>( &mut self, src: &Buffer<T, A1>, dst: &mut Buffer<T, A2>, ) -> Event
where T: Pod, A1: UsmAlloc, A2: UsmAlloc,

Copies the contents of the source buffer to the destination buffer.

If the buffer sizes don’t match the destination buffer is filled with as many elements from source buffer as possible.

pub fn copy_with_deps<T, A1, A2>( &mut self, src: &Buffer<T, A1>, dst: &mut Buffer<T, A2>, dep_events: &[&Event], ) -> Event
where T: Pod, A1: UsmAlloc, A2: UsmAlloc,

Copies the contents of the source buffer to the destination buffer after all specified events finish.

If the buffer sizes don’t match the destination buffer is filled with as many elements from source buffer as possible.